powered by
Retrieve the color used by default for a given ggcharts theme
ggcharts
ggcharts_get_default_color(theme)
character. The name of a ggcharts theme.
character
The default color for the given theme as a character
# NOT RUN { ggcharts_get_default_color("theme_hermit") ggcharts_get_default_color("theme_ng") # }
Run the code above in your browser using DataLab